"""每日开放资源关卡"""
import nonebot
from nonebot import logger
from nonebot import on_regex
from nonebot.permission import SUPERUSER
from nonebot_plugin_apscheduler import scheduler

from .config import Config
from .data_source import get_daily_sources

global_config = nonebot.get_driver().config
ark_daily_config = Config(**global_config.dict())

material = on_regex(r"方舟今[日|天]*[资源]*[材料]*", priority=5, block=True)
super_cmd = on_regex(r"更新方舟今[日|天]*[资源]*[材料]*", permission=SUPERUSER, priority=1, block=True)


@material.handle()
async def _():
    rst_img = await get_daily_sources()
    if rst_img:
        rst = rst_img
    else:
        rst = f"方舟今日资源截图失败！请更换至非windows平台部署本插件\n或检查网络连接并稍后重试"
    await material.finish(rst)


@super_cmd.handle()
async def _():
    try:
        await get_daily_sources(is_force=True)
    except Exception as e:
        logger.error(f"方舟今日资源更新失败！{type(e)}: {e}")
        await super_cmd.finish(f"方舟今日资源更新失败！请稍后重试！")
    else:
        await super_cmd.finish(f"方舟今日资源更新完成！")


@scheduler.scheduled_job(
    "cron",
    hour=4,
    minute=1,
)
async def _():
    try:
        await get_daily_sources(is_force=True)
    except Exception as e:
        logger.error(f"方舟今日资源更新失败！{type(e)}: {e}")



import asyncio
import base64
import os
from datetime import datetime, timedelta
from io import BytesIO

from pathlib import Path
from PIL import Image
from nonebot import get_driver, logger
from nonebot.adapters.onebot.v11 import Message, MessageSegment
from playwright._impl._api_types import TimeoutError

from .config import Config
from .._utils import get_browser


ark_daily_config = Config.parse_obj(get_driver().config.dict())
DAILY_LEVELS_PATH = Path(ark_daily_config.daily_levels_path)

async def get_daily_sources(is_force: bool = False):
    """获取每日资源关卡"""
    os.mkdir(DAILY_LEVELS_PATH) if not os.path.exists(DAILY_LEVELS_PATH) else None
    today = str((datetime.now() - timedelta(hours=4)).date())
    file_name = DAILY_LEVELS_PATH / f"{today}.png"
    if file_name.exists() and not is_force:
        return Message(MessageSegment.image(file_name) + f"{today} - 数据来源于 https://prts.wiki/")

    page = None
    for retry in range(3):
        try:
            browser = await get_browser()
            if not browser:
                return None
            url = "https://prts.wiki/"
            page = await browser.new_page()
            await page.goto(url, timeout=10000)
            await page.set_viewport_size({"width": 1920, "height": 1080})
            result = await page.query_selector('div[class="mp-container-left"]')
            await page.wait_for_selector("img", state="visible")
            await result.scroll_into_view_if_needed()
            box = await result.bounding_box()
            box['x'] -= 25
            box['y'] -= 55
            box['width'] -= 130
            box['height'] += 70
            await asyncio.sleep(1)
            screenshot = await page.screenshot(clip=box)
        except TimeoutError:
            logger.warning(f"第{retry + 1}次获取方舟每日资源截图失败……")
            continue
        except AttributeError:
            logger.warning(f"第{retry + 1}次获取方舟每日资源截图失败……")
            continue
        except Exception as e:
            if page:
                await page.close()
            logger.error(f"方舟每日资源截图失败！ - {type(e)}: {e}")
            return None
        else:
            await page.close()
            b_scr = BytesIO(screenshot)
            img = Image.open(b_scr)
            img.save(file_name)
            return Message(
                MessageSegment.image(base64.b64encode(screenshot)) + f"{today} - 数据来源于 https://prts.wiki/")
    if page:
        await page.close()
    return None



import httpx
import os
import json
import asyncio
import base64

from lxml import etree
from nonebot import get_driver, logger

from PIL import Image
from .._utils import async_GET
from .._utils import get_browser
from nonebot.adapters.onebot.v11 import MessageSegment
from playwright._impl._api_types import TimeoutError
from nonebot.adapters.onebot.v11 import Message
from io import BytesIO
from pathlib import Path

from .config import Config

activity_config = Config.parse_obj(get_driver().config.dict())
DATA_PATH = Path(activity_config.activities_data_path)
IMG_PATH = Path(activity_config.activities_img_path)


async def get_activities(*, is_force: bool = False, is_cover: bool = False):
    """获取近期活动"""
    activity_data = {}
    announcement_url = "https://ak.hypergryph.com/news.html"
    result = None
    for retry in range(5):
        try:
            result = await async_GET(url=announcement_url)
        except httpx.TimeoutException:
            logger.warning(f"获取方舟近期活动第{retry + 1}次失败...")
            continue
        else:
            break
    if not result:
        return None
    text = result.text
    dom = etree.HTML(text, etree.HTMLParser())
    activity_urls = dom.xpath(
        "//ol[@class='articleList' and @data-category-key='ACTIVITY']/li/a/@href"
    )[:3]
    activity_titles = dom.xpath(
        "//ol[@class='articleList' and @data-category-key='ACTIVITY']/li/a/h1/text()"
    )[:3]
    activity_times = dom.xpath(
        "//ol[@class='articleList' and @data-category-key='ACTIVITY']/li/a/span[@class='articleItemDate']/text()"
    )[:3]
    for idx, time in enumerate(activity_times):
        activity_data[time] = {
            "url": f"https://ak.hypergryph.com{activity_urls[idx]}",
            "title": activity_titles[idx].strip()
        }
    if not os.path.exists(DATA_PATH):
        os.makedirs(DATA_PATH)
    if not os.path.exists(DATA_PATH / "activities.json"):
        with open(DATA_PATH / "activities.json", 'w', encoding='utf-8') as f:
            json.dump({}, f)
    update_flag = await write_in_data(activity_data, activity_times[0])
    if update_flag or is_force:
        latest = activity_times[0]
        msg = await get_latest_info(activity_data, latest, is_cover=is_cover)
        if msg:
            return msg
        return None
    return None


async def write_in_data(activity_data: dict, latest: str) -> bool:
    """把最新的三条活动信息写入文件"""
    update_flag = False
    with open(DATA_PATH / "activities.json", 'r', encoding='utf-8') as f_read:
        old_data = json.load(f_read)
        if old_data and old_data['latest'] not in activity_data.keys():
            update_flag = True
            with open(DATA_PATH / "activities.json", 'w', encoding='utf-8') as f_write:
                json.dump(
                    {"latest": latest, "details": activity_data}
                    , f_write
                )
    return update_flag


async def get_latest_info(activity_data: dict, latest: str, *, is_cover: bool = False):
    """截图最新活动"""
    if not os.path.exists(IMG_PATH):
        os.makedirs(IMG_PATH)

    value = activity_data[latest]
    url = value['url']
    title = value['title']
    file_name = IMG_PATH / f"{title}.png"
    if file_name.exists() and not is_cover:
        return Message(
            f"{MessageSegment.image(file_name)}"
            f"{title}\n"
            f"公告更新日期(不是活动开始日期): {latest}\n"
            f"数据来源于: {url}"
        )

    page = None
    for retry in range(3):
        try:
            browser = await get_browser()
            if not browser:
                return None
            page = await browser.new_page()
            await page.goto(url, timeout=10000)
            await page.set_viewport_size({"width": 960, "height": 1080})
            await asyncio.sleep(1)
            screenshot = await page.screenshot(full_page=True, type='jpeg', quality=50)
        except TimeoutError:
            logger.warning(f"第{retry + 1}次获取方舟活动截图失败……")
            continue
        except Exception as e:
            if page:
                await page.close()
            logger.error(f"方舟活动截图失败！ - {type(e)}: {e}")
            return None
        else:
            await page.close()
            b_scr = BytesIO(screenshot)
            img = Image.open(b_scr)
            img.save(file_name)
            return Message(
                f"{MessageSegment.image(base64.b64encode(screenshot))}"
                f"{title}\n"
                f"公告更新日期: {latest}\n"
                f"数据来源于: {url}"
            )
    if page:
        await page.close()
    return None



import setuptools


with open("README.md", "r", encoding='utf-8') as f:
    long_description = f.read()


setuptools.setup(
    name="nonebot_plugin_arktools",
    version="0.1.4",
    author="Number_Sir",
    author_email="Number_Sir@126.com",
    keywords=["pip", "nonebot2", "nonebot", "nonebot_plugin"],
    description="""基于 OneBot 适配器的 NoneBot2 明日方舟小工具箱插件""",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/NumberSir/nonebot_plugin_arktools",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    include_package_data=True,
    platforms="any",
    install_requires=[
        'nonebot-adapter-onebot>=2.0.0-beta.1',
        'nonebot2>=2.0.0-beta.1',
        'httpx>=0.22.0',
        'pillow>=8.2.0',
        'playwright>=1.22.0',
    ],
    python_requires=">=3.9"
)



import httpx
from nonebot import logger


async def async_GET(url, *, retry: int = 5, **kwargs):
    async with httpx.AsyncClient() as client:
        for times in range(retry):
            try:
                return await client.get(url, **kwargs)
            except httpx.TimeoutException:
                logger.warning(f"请求第{times+1}次失败...")
                continue
            except Exception:
                raise
        raise
